@@ -19,6 +19,7 @@ import org.gnu.glib.Type;
  * always one GnomeCanvasGroup in a GnomeCanvas.
  */
 public class CanvasGroup extends CanvasItem {
+	
 	/**
 	 * Constructs an instance of CanvasGroup from a native widget resource.
 	 * @param handle The handle to the native widget.
@@ -26,6 +27,17 @@ public class CanvasGroup extends CanvasItem {
 	CanvasGroup(int handle) {
 		super(handle);
 	}
+	
+	public CanvasItem[] getItems() {
+		int[] hndls = get_item_list(getHandle());
+		if (null == hndls)
+			return null;
+		CanvasItem[] values = new CanvasItem[hndls.length];
+		for (int i = 0; i < hndls.length; i++) {
+			values[i] = new CanvasItem(hndls[i]);
+		}
+		return values;
+	}
 
 	/**
 	 * Retrieve the runtime type used by the GLib library.
@@ -38,6 +50,7 @@ public class CanvasGroup extends CanvasItem {
 	 * BEGINNING OF GENERATED CODE
 	 ****************************************/
 	native static final protected int gnome_canvas_group_get_type();
+	native static final protected int[] get_item_list(int group);
 	/****************************************
 	 * END OF GENERATED CODE
 	 ****************************************/
